@@ -20,20 +20,20 @@
  * Author: Christian Kellner <gicmo@gnome.org> 
  */
 
-#include <config.h>
+#include "config.h"
 #include "gmemoryinputstream.h"
 #include "ginputstream.h"
 #include "gseekable.h"
 #include "string.h"
 #include "gsimpleasyncresult.h"
+#include "gioerror.h"
 #include "glibintl.h"
 
-#include "gioalias.h"
 
 /**
  * SECTION:gmemoryinputstream
  * @short_description: Streaming input operations on memory chunks
- * @include: gio.h
+ * @include: gio/gio.h
  * @see_also: #GMemoryOutputStream
  *
  * #GMemoryInputStream is a class for using arbitrary
@@ -163,8 +163,7 @@ g_memory_input_stream_finalize (GObject *object)
   g_slist_foreach (priv->chunks, free_chunk, NULL);
   g_slist_free (priv->chunks);
 
-  if (G_OBJECT_CLASS (g_memory_input_stream_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_memory_input_stream_parent_class)->finalize) (object);
+  G_OBJECT_CLASS (g_memory_input_stream_parent_class)->finalize (object);
 }
 
 static void
@@ -185,6 +184,13 @@ g_memory_input_stream_init (GMemoryInputStream *stream)
                                               GMemoryInputStreamPrivate);
 }
 
+/**
+ * g_memory_input_stream_new:
+ *
+ * Creates a new empty #GMemoryInputStream. 
+ *
+ * Returns: a new #GInputStream
+ */
 GInputStream *
 g_memory_input_stream_new (void)
 {
@@ -197,9 +203,9 @@ g_memory_input_stream_new (void)
 
 /**
  * g_memory_input_stream_new_from_data:
- * @data: input data
+ * @data: (array length=len) (element-type guint8): input data
  * @len: length of the data, may be -1 if @data is a nul-terminated string
- * @destroy: function that is called to free @data, or %NULL
+ * @destroy: (allow-none): function that is called to free @data, or %NULL
  *
  * Creates a new #GMemoryInputStream with data in memory of a given size.
  * 
@@ -220,6 +226,15 @@ g_memory_input_stream_new_from_data (const void     *data,
   return stream;
 }
 
+/**
+ * g_memory_input_stream_add_data:
+ * @stream: a #GMemoryInputStream
+ * @data: (array length=len) (element-type guint8): input data
+ * @len: length of the data, may be -1 if @data is a nul-terminated string
+ * @destroy: (allow-none): function that is called to free @data, or %NULL
+ *
+ * Appends @data to data that can be read from the input stream
+ */
 void
 g_memory_input_stream_add_data (GMemoryInputStream *stream,
                                 const void         *data,
@@ -283,7 +298,7 @@ g_memory_input_stream_read (GInputStream  *stream,
       chunk = (Chunk *)l->data;
       size = MIN (rest, chunk->len - start);
 
-      memcpy (buffer + (count - rest), chunk->data + start, size);
+      memcpy ((guint8 *)buffer + (count - rest), chunk->data + start, size);
       rest -= size;
 
       start = 0;
@@ -465,20 +480,20 @@ g_memory_input_stream_seek (GSeekable     *seekable,
       break;
   
     default:
-      g_set_error (error,
-                   G_IO_ERROR,
-                   G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Invalid GSeekType supplied"));
+      g_set_error_literal (error,
+                           G_IO_ERROR,
+                           G_IO_ERROR_INVALID_ARGUMENT,
+                           _("Invalid GSeekType supplied"));
 
       return FALSE;
     }
 
   if (absolute < 0 || absolute > priv->len)
     {
-      g_set_error (error,
-                   G_IO_ERROR,
-                   G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Invalid seek request"));
+      g_set_error_literal (error,
+                           G_IO_ERROR,
+                           G_IO_ERROR_INVALID_ARGUMENT,
+                           _("Invalid seek request"));
       return FALSE;
     }
 
@@ -499,12 +514,9 @@ g_memory_input_stream_truncate (GSeekable     *seekable,
                                 GCancellable  *cancellable,
                                 GError       **error)
 {
-  g_set_error (error,
-               G_IO_ERROR,
-               G_IO_ERROR_NOT_SUPPORTED,
-               _("Cannot truncate GMemoryInputStream"));
+  g_set_error_literal (error,
+                       G_IO_ERROR,
+                       G_IO_ERROR_NOT_SUPPORTED,
+                       _("Cannot truncate GMemoryInputStream"));
   return FALSE;
 }
-
-#define __G_MEMORY_INPUT_STREAM_C__
-#include "gioaliasdef.c"
